# Alveolus Documentation Package
Alveolus is a small package that makes your C++ Documentation process easier. Using Breathe and Exhale you can combine 
your C++ Code Documentation with your Custom API doxumentation written in simple .rst files .
This projects relies heavily on Doxygen+Sphinx+Breathe+Exhale but makes the process of combining them nad using them 
easier. Run alveolus-build in any c++ project and an index html with the ReadTheDocs theme will be created instantly

## Installation Instructions

## Dependencies

## Credit

## License
